@@ -1,4 +1,9 @@
-## Copyright (C) 2006-2019 Bill Denney
+########################################################################
+##
+## Copyright (C) 2006-2021 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} gunzip (@var{gzfile})
@@ -32,8 +39,6 @@
 ## @seealso{gzip, unpack, bunzip2, unzip, untar}
 ## @end deftypefn
 
-## Author: Bill Denney <denney@seas.upenn.edu>
-
 function filelist = gunzip (gzfile, dir = [])
 
   if (nargin < 1 || nargin > 2)
