@@ -1,20 +1,27 @@
-## Copyright (C) 2013-2017 Michael D. Godfrey
+########################################################################
+##
+## Copyright (C) 2013-2021 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} stemleaf (@var{x}, @var{caption})
@@ -68,14 +75,11 @@
 ## @code{@var{xs} = sort (@var{x})} before calling @code{stemleaf (@var{xs})}.
 ##
 ## The stem and leaf plot and associated displays are described in:
-## Chapter 3, @cite{Exploratory Data Analysis} by J. W. Tukey, Addison-Wesley,
-## 1977.
+## Chapter 3, @cite{Exploratory Data Analysis} by @nospell{J. W. Tukey},
+## Addison-Wesley, 1977.
 ## @seealso{hist, printd}
 ## @end deftypefn
 
-## Author: Michael D. Godfrey <michaeldgodfrey@gmail.com>
-## Description: Compute stem and leaf plot
-
 function plotstr = stemleaf (x, caption, stem_sz)
   ## Compute and display a stem and leaf plot of the vector x.  The x
   ## vector is converted to integer by x = fix(x).  If an output argument
@@ -155,12 +159,11 @@ function plotstr = stemleaf (x, caption, stem_sz)
   if (nargin == 2)
     stem_step = 10;
   else
-    if (isscalar (stem_sz) && stem_sz >= 0 && isreal (stem_sz))
-      stem_sz = fix (stem_sz);
-      stem_step = 10^(stem_sz+1);
-    else
+    if (! (isscalar (stem_sz) && stem_sz >= 0 && isreal (stem_sz)))
       error ("stemleaf: STEM_SZ must be a real integer >= 0");
     endif
+    stem_sz = fix (stem_sz);
+    stem_step = 10^(stem_sz+1);
   endif
 
   ## Note that IEEE 754 states that -+ 0 should compare equal.  This has
@@ -246,7 +249,7 @@ function plotstr = stemleaf (x, caption, stem_sz)
   ## Vectorized version provided by Rik Wehbring (rik@octave.org)
   ## Determine leaves for each stem:
   new_line = 1;
-  for kx = 2: numel (stems)
+  for kx = 2 : numel (stems)
 
     stem_sign = signbit (stems(kx));
     if (stems(kx) <= 0)
